@@ -1,6 +1,6 @@
 import base64
 
-from flask import request, abort, redirect, url_for, flash, render_template
+from flask import request, abort, redirect, url_for, flash
 from jinja2.loaders import ChoiceLoader, PackageLoader
 from flask.ext.admin import expose
 from flask.ext.admin.model import BaseModelView
@@ -24,7 +24,7 @@ class OpenERPModelView(BaseModelView):
             relation = self.model.client.model(relation)
             remote_ids = relation.search([])
             field = getattr(form, choice_field)
-            field.choices = relation.name_get(remote_ids)
+            field.choices = [(0, '')] + relation.name_get(remote_ids)
 
     def edit_form(self, obj):
         """Updates the choices for dynamic fields.
@@ -151,8 +151,8 @@ class OpenERPModelView(BaseModelView):
         return n_items, res
 
     def write_data(self, origin_data, columns):
-        if origin_data != None:
-            return {key: value for key, value in origin_data.items()
+        if origin_data is not None:
+            return {key: value for key, value in origin_data
                          if key in columns}
         else:
             return origin_data
